==> hubzero-submit-monitors_3.10.1-1+deb10.tar.gz: source/monitorCloud.py <==
#!/usr/bin/env python3
#
# @package      hubzero-submit-monitors
# @file         monitorCloud.py
# @copyright    Copyright (c) 2004-2020 The Regents of the University of California.
# @license      http://opensource.org/licenses/MIT MIT
#
# Copyright (c) 2004-2020 The Regents of the University of California.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#
# HUBzero is a registered trademark of The Regents of the University of California.
#
# ----------------------------------------------------------------------
#  monitorCloud.py
#
#  script which monitors a cloud instance for use with distributor and related processes.
#
import sys
import os
import time
import logging

from hubzero.submit.ApplicationUtilities import ApplicationUtilities as ApplicationUtilities
from hubzero.submit.MonitorCloud         import MonitorCloud

MONITORLOGLEVEL = "INFO"

MONITORROOT        = os.path.dirname(os.path.abspath(__file__))
MONITORLOGLOCATION = os.path.join(os.sep,'var','log','submit','monitors')
MONITORLOGFILENAME = "monitorCloud.log"

PIDFILE = os.path.join(os.sep,'var','run','submit','submit-cloud.pid')

DUMPFILENAME = "monitorCloud.dump"
DUMPFILEPATH = os.path.join(MONITORROOT,DUMPFILENAME)

DAEMONSDIRECTORY         = os.path.join(os.sep,"etc","submit")
DAEMONSCONFIGURATIONFILE = 'daemons.conf'
INFOSDIRECTORY           = os.path.join(os.sep,"etc","submit")
INFOSCONFIGURATIONFILE   = 'infos.conf'

ACTIVITYUPDATEINTERVAL = 15.*60.

if __name__ == '__main__':
   monitorLogLevel          = os.getenv("MONITORLOGLEVEL",MONITORLOGLEVEL)
   monitorLogLocation       = os.getenv("MONITORLOGLOCATION",MONITORLOGLOCATION)
   monitorLogFilename       = os.getenv("MONITORLOGFILENAME",MONITORLOGFILENAME)
   monitorPidFile           = os.getenv("MONITORPIDFILE",MONITORPIDFILE)
   daemonsDirectory         = os.getenv("DAEMONSDIRECTORY",DAEMONSDIRECTORY)
   daemonsConfigurationFile = os.getenv("DAEMONSCONFIGURATIONFILE",DAEMONSCONFIGURATIONFILE)
   infosDirectory           = os.getenv("INFOSDIRECTORY",INFOSDIRECTORY)
   infosConfigurationFile   = os.getenv("INFOSCONFIGURATIONFILE",INFOSCONFIGURATIONFILE)
   activityUpdateInterval   = os.getenv("ACTIVITYUPDATEINTERVAL",ACTIVITYUPDATEINTERVAL)

   applicationUtilities = ApplicationUtilities(MONITORLOGLEVEL)
   applicationUtilities.openFileLogger(monitorLogLocation,monitorLogFilename,
                                       monitorLogLevel):
   applicationUtilities.daemonize()
   applicationUtilities.writePidFile(monitorPidFile)

   monitorCloud = MonitorCloud(MONITORROOT,
                               daemonsDirectory,daemonsConfigurationFile,
                               infosDirectory,infosConfigurationFile,
                               DUMPFILEPATH,
                               activityUpdateInterval)
   monitorCloud.monitor()

==> hubzero-submit-monitors_3.11.1-1+deb10.tar.gz: source/monitorCloud.py <==
#!/usr/bin/env python3
#
# @package      hubzero-submit-monitors
# @file         monitorCloud.py
# @copyright    Copyright (c) 2004-2020 The Regents of the University of California.
# @license      http://opensource.org/licenses/MIT MIT
#
# Copyright (c) 2004-2020 The Regents of the University of California.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#
# HUBzero is a registered trademark of The Regents of the University of California.
#
# ----------------------------------------------------------------------
#  monitorCloud.py
#
#  script which monitors a cloud instance for use with distributor and related processes.
#
import sys
import os
import time
import logging

from hubzero.submit.ApplicationUtilities import ApplicationUtilities as ApplicationUtilities
from hubzero.submit.MonitorCloud         import MonitorCloud

MONITORLOGLEVEL         = "INFO"
MONITORSYSLOGLOCAL      = "LOCAL3"
MONITORSYSLOGIDENTIFIER = "SUBMITCLOUDMON"

MONITORROOT        = os.path.dirname(os.path.abspath(__file__))

PIDFILE = os.path.join(os.sep,'var','run','submit','submit-cloud.pid')

DUMPFILENAME = "monitorCloud.dump"
DUMPFILEPATH = os.path.join(MONITORROOT,DUMPFILENAME)

DAEMONSDIRECTORY         = os.path.join(os.sep,"etc","submit")
DAEMONSCONFIGURATIONFILE = 'daemons.conf'
INFOSDIRECTORY           = os.path.join(os.sep,"etc","submit")
INFOSCONFIGURATIONFILE   = 'infos.conf'

ACTIVITYUPDATEINTERVAL = 15.*60.

if __name__ == '__main__':
   monitorLogLevel          = os.getenv("MONITORLOGLEVEL",MONITORLOGLEVEL)
   monitorSysLogLocal       = os.getenv("MONITORSYSLOGLOCAL",MONITORSYSLOGLOCAL)
   monitorSysLogIdentifier  = os.getenv("MONITORSYSLOGIDENTIFIER",MONITORSYSLOGIDENTIFIER)
   monitorPidFile           = os.getenv("MONITORPIDFILE",MONITORPIDFILE)
   daemonsDirectory         = os.getenv("DAEMONSDIRECTORY",DAEMONSDIRECTORY)
   daemonsConfigurationFile = os.getenv("DAEMONSCONFIGURATIONFILE",DAEMONSCONFIGURATIONFILE)
   infosDirectory           = os.getenv("INFOSDIRECTORY",INFOSDIRECTORY)
   infosConfigurationFile   = os.getenv("INFOSCONFIGURATIONFILE",INFOSCONFIGURATIONFILE)
   activityUpdateInterval   = os.getenv("ACTIVITYUPDATEINTERVAL",ACTIVITYUPDATEINTERVAL)

   applicationUtilities = ApplicationUtilities(MONITORLOGLEVEL,
                                               defaultSysLogLocal=MONITORSYSLOGLOCAL)
   applicationUtilities.openSysLogLogger(monitorSysLogLocal,
                                         monitorLogLevel,
                                         logIdentifier=monitorSysLogIdentifier)
   applicationUtilities.daemonize()
   applicationUtilities.writePidFile(monitorPidFile)

   monitorCloud = MonitorCloud(MONITORROOT,
                               daemonsDirectory,daemonsConfigurationFile,
                               infosDirectory,infosConfigurationFile,
                               DUMPFILEPATH,
                               activityUpdateInterval)
   monitorCloud.monitor()
